@@ -1,6 +1,6 @@
 /*
   File name: CCytadelaMain.cpp
-  Copyright: (C) 2005 - 2010 Tomasz Kazmierczak
+  Copyright: (C) 2005 - 2013 Tomasz Kazmierczak
 
   This file is part of Cytadela
 
@@ -156,7 +156,7 @@ bool CCytadelaMain::configScreen(CCytadelaConfig *config)
 	fprintf(stdout, "------------------------------------------------------------\n");
 	fprintf(stdout, "Reading the OpenGL vrsion and extensions...   \n");
 	//switch to OpenGL mode to check the version
-	if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, MODE_3D)) {
+	if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, CSDLClass::Mode3D)) {
 		fprintf(stdout, "\nError: Could not initialize OpenGL!\nExiting...\n");
 		return false;
 	}
@@ -168,7 +168,11 @@ bool CCytadelaMain::configScreen(CCytadelaConfig *config)
 	fprintf(stdout, "Done\n");
 	fprintf(stdout, "Switching to 2D video mode...   ");
 	//now switch to the 2D mode
-	if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, MODE_2D)) {
+	CSDLClass::ScreenMode smode;
+	if(CCytadelaConfig::instance()->isFullScreen())
+		smode = CSDLClass::FullScreen;
+	else smode = CSDLClass::Windowed;
+	if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, CSDLClass::Mode2D, smode)) {
 		fprintf(stdout, "\nError: Could not initialize SDL Video mode!\nExiting...\n");
 		return false;
 	}
@@ -357,7 +361,7 @@ bool CCytadelaMain::configScreen(CCytadelaConfig *config)
 			return false;
 		}
 		if(key == SDLK_RETURN) {
-			sprintf(localizationName, entryNames[chosenLocalization].c_str());
+			sprintf(localizationName, "%s", entryNames[chosenLocalization].c_str());
 			break;
 		}
 		if(key == SDLK_UP) {
@@ -586,7 +590,7 @@ bool CCytadelaMain::endLevel()
 	mSDL->playMusic(-1);
 	//display text
 	char text[40];
-	sprintf(text, mSaveNames[mLevel]);
+	sprintf(text, "%s", mSaveNames[mLevel]);
 	char levelNum = text[strlen(text) - 1];
 	text[strlen(text) - 1] = 0;
 	sprintf(text, "%s%s %c %s!", text, mLocalization->getText(LOC_END_LEVEL),
@@ -977,8 +981,8 @@ bool CCytadelaMain::playIntro()
 
 	bool ok;
 	if(strcmp(mLocalization->getCurrentLocalization(), CYTADELA_DEFAULT_LOCALIZATION) == 0)
-		ok = mSDL->playVideo("video/intro_pl.ogv", true, true);
-	else ok = mSDL->playVideo("video/intro_en.ogv", true, true);
+		ok = mSDL->playVideo("video/intro_pl.webm", true, true);
+	else ok = mSDL->playVideo("video/intro_en.webm", true, true);
 	if(not ok)
 		return false;
 	
@@ -1001,8 +1005,8 @@ bool CCytadelaMain::playOutro()
 
 	bool ok;
 	if(strcmp(mLocalization->getCurrentLocalization(), CYTADELA_DEFAULT_LOCALIZATION) == 0)
-		ok = mSDL->playVideo("video/outro_pl.ogv", false, false);
-	else ok = mSDL->playVideo("video/outro_en.ogv", false, false);
+		ok = mSDL->playVideo("video/outro_pl.webm", false, false);
+	else ok = mSDL->playVideo("video/outro_en.webm", false, false);
 	if(not ok)
 		return false;
 
@@ -1165,8 +1169,8 @@ void CCytadelaMain::runMain()
 			//check the configuration that might have changed in the menu
 			const int32_t *screenSize = config->getScreenSize();
 			mState.difficult = config->isDifficult();
-			if(not mSDL->switchVideoMode(screenSize[0], screenSize[1], MODE_3D)) {
-				if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, MODE_2D))
+			if(not mSDL->switchVideoMode(screenSize[0], screenSize[1], CSDLClass::Mode3D)) {
+				if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, CSDLClass::Mode2D))
 					break;
 				//display information about the error that occured
 				if(not errorScreen("ERROR WHILE SETTING VIDEO MODE!"))
@@ -1175,7 +1179,7 @@ void CCytadelaMain::runMain()
 			}
 			if(not openGL.initOGL(screenSize[0], screenSize[1])) {
 				openGL.freeOGL();
-				if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, MODE_2D))
+				if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, CSDLClass::Mode2D))
 					break;
 				//display information about the error that occured
 				if(not errorScreen("ERROR WHILE INITIALIZING OPENGL!"))
@@ -1186,7 +1190,7 @@ void CCytadelaMain::runMain()
 				not game.runGame(mLevels[mLevel], &mState)) {
 				game.freeGame();
 				openGL.freeOGL();
-				if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, MODE_2D))
+				if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, CSDLClass::Mode2D))
 					break;
 				//display information about the error that occured
 				if(not errorScreen(game.getLastErrorDesc()))
@@ -1195,7 +1199,7 @@ void CCytadelaMain::runMain()
 			}
 			game.freeGame();
 			openGL.freeOGL();
-			if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, MODE_2D))
+			if(not mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, CSDLClass::Mode2D))
 				break;
 
 			mSDL->blackScreen();
