@@ -1,6 +1,6 @@
 /*
   File name: CCytadelaMenu.cpp
-  Copyright: (C) 2004 - 2010 Tomasz Kazmierczak
+  Copyright: (C) 2004 - 2013 Tomasz Kazmierczak
 
   This file is part of Cytadela
   (an example of how NOT to design in-game menu)
@@ -32,26 +32,26 @@ CCytadelaMenu::CCytadelaMenu() :
 	//menu texts and text positions
 	//MAIN MENU
 	const char *text = mLocalization->getText(LOC_MENU_START);
-	sprintf(mMenuTexts[MENU_MAIN][0], text);
+	sprintf(mMenuTexts[MENU_MAIN][0], "%s", text);
 	mMenuTextsXOffs[MENU_MAIN][0] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_LOAD);
-	sprintf(mMenuTexts[MENU_MAIN][1], text);
+	sprintf(mMenuTexts[MENU_MAIN][1], "%s", text);
 	mMenuTextsXOffs[MENU_MAIN][1] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_OPTIONS);
-	sprintf(mMenuTexts[MENU_MAIN][2], text);
+	sprintf(mMenuTexts[MENU_MAIN][2], "%s", text);
 	mMenuTextsXOffs[MENU_MAIN][2] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_TRAINING);
-	sprintf(mMenuTexts[MENU_MAIN][3], text);
+	sprintf(mMenuTexts[MENU_MAIN][3], "%s", text);
 	mMenuTextsXOffs[MENU_MAIN][3] = 120 - (strlen(text) * 8);
 
 	mMenuTexts[MENU_MAIN][4][0] = 0;
 	mMenuTextsXOffs[MENU_MAIN][4] = 0;
 
 	text = mLocalization->getText(LOC_MENU_INFO);
-	sprintf(mMenuTexts[MENU_MAIN][5], text);
+	sprintf(mMenuTexts[MENU_MAIN][5], "%s", text);
 	mMenuTextsXOffs[MENU_MAIN][5] = 120 - (strlen(text) * 8);
 
 	//LOAD MENU
@@ -61,7 +61,7 @@ CCytadelaMenu::CCytadelaMenu() :
 		mMenuTexts[MENU_LOAD][i][0] = 0;
 	}
 	text = mLocalization->getText(LOC_MENU_MENU);
-	sprintf(mMenuTexts[MENU_LOAD][5], text);
+	sprintf(mMenuTexts[MENU_LOAD][5], "%s", text);
 	mMenuTextsXOffs[MENU_LOAD][5] = 120 - (strlen(text) * 8);
 
 	//OPTIONS menu
@@ -69,47 +69,47 @@ CCytadelaMenu::CCytadelaMenu() :
 	mMenuTexts[MENU_SETTINGS][0][0] = 0;
 
 	text = mLocalization->getText(LOC_MENU_VIDEO_OPTIONS);
-	sprintf(mMenuTexts[MENU_SETTINGS][1], text);
+	sprintf(mMenuTexts[MENU_SETTINGS][1], "%s", text);
 	mMenuTextsXOffs[MENU_SETTINGS][1] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_SPEED_SETTINGS);
-	sprintf(mMenuTexts[MENU_SETTINGS][2], text);
+	sprintf(mMenuTexts[MENU_SETTINGS][2], "%s", text);
 	mMenuTextsXOffs[MENU_SETTINGS][2] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_AUDIO_SETTINGS);
-	sprintf(mMenuTexts[MENU_SETTINGS][3], text);
+	sprintf(mMenuTexts[MENU_SETTINGS][3], "%s", text);
 	mMenuTextsXOffs[MENU_SETTINGS][3] = 120 - (strlen(text) * 8);
 
 	mMenuTextsXOffs[MENU_SETTINGS][4] = 0;
 	mMenuTexts[MENU_SETTINGS][4][0] = 0;
 
 	text = mLocalization->getText(LOC_MENU_MENU);
-	sprintf(mMenuTexts[MENU_SETTINGS][5], text);
+	sprintf(mMenuTexts[MENU_SETTINGS][5], "%s", text);
 	mMenuTextsXOffs[MENU_SETTINGS][5] = 120 - (strlen(text) * 8);
 
 	//TRAINING MENU
 	text = mLocalization->getText(LOC_MENU_TRAINING_1);
-	sprintf(mMenuTexts[MENU_TRAINING][0], text);
+	sprintf(mMenuTexts[MENU_TRAINING][0], "%s", text);
 	mMenuTextsXOffs[MENU_TRAINING][0] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_TRAINING_2);
-	sprintf(mMenuTexts[MENU_TRAINING][1], text);
+	sprintf(mMenuTexts[MENU_TRAINING][1], "%s", text);
 	mMenuTextsXOffs[MENU_TRAINING][1] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_TRAINING_3);
-	sprintf(mMenuTexts[MENU_TRAINING][2], text);
+	sprintf(mMenuTexts[MENU_TRAINING][2], "%s", text);
 	mMenuTextsXOffs[MENU_TRAINING][2] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_TRAINING_4);
-	sprintf(mMenuTexts[MENU_TRAINING][3], text);
+	sprintf(mMenuTexts[MENU_TRAINING][3], "%s", text);
 	mMenuTextsXOffs[MENU_TRAINING][3] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_TRAINING_5);
-	sprintf(mMenuTexts[MENU_TRAINING][4], text);
+	sprintf(mMenuTexts[MENU_TRAINING][4], "%s", text);
 	mMenuTextsXOffs[MENU_TRAINING][4] = 120 - (strlen(text) * 8);
 
 	text = mLocalization->getText(LOC_MENU_MENU);
-	sprintf(mMenuTexts[MENU_TRAINING][5], text);
+	sprintf(mMenuTexts[MENU_TRAINING][5], "%s", text);
 	mMenuTextsXOffs[MENU_TRAINING][5] = 120 - (strlen(text) * 8);
 
 	//GFX OPTIONS menu
@@ -118,7 +118,7 @@ CCytadelaMenu::CCytadelaMenu() :
 		mMenuTexts[MENU_VIDEO][i][0] = 0;
 	}
 	text = mLocalization->getText(LOC_MENU_MENU);
-	sprintf(mMenuTexts[MENU_VIDEO][5], text);
+	sprintf(mMenuTexts[MENU_VIDEO][5], "%s", text);
 	mMenuTextsXOffs[MENU_VIDEO][5] = 120 - (strlen(text) * 8);
 
 	//GAME SPEED menu
@@ -127,7 +127,7 @@ CCytadelaMenu::CCytadelaMenu() :
 		mMenuTexts[MENU_GAME_SPEED][i][0] = 0;
 	}
 	text = mLocalization->getText(LOC_MENU_MENU);
-	sprintf(mMenuTexts[MENU_GAME_SPEED][5], text);
+	sprintf(mMenuTexts[MENU_GAME_SPEED][5], "%s", text);
 	mMenuTextsXOffs[MENU_GAME_SPEED][5] = 120 - (strlen(text) * 8);
 
 	//AUDIO SETTINGS menu
@@ -136,14 +136,14 @@ CCytadelaMenu::CCytadelaMenu() :
 		mMenuTexts[MENU_AUDIO][i][0] = 0;
 	}
 	text = mLocalization->getText(LOC_MENU_MENU);
-	sprintf(mMenuTexts[MENU_AUDIO][5], text);
+	sprintf(mMenuTexts[MENU_AUDIO][5], "%s", text);
 	mMenuTextsXOffs[MENU_AUDIO][5] = 120 - (strlen(text) * 8);
 
 	//set the info texts
 	static const char *defaultLang =
 "                               ...CYTADELA...\n"
-"                                 WERSJA 1.0.1\n"
-"                 COPYRIGHT (C) 2003-2010 TOMASZ KAxMIERCZAK\n"
+"                                 WERSJA 1.1.0\n"
+"                 COPYRIGHT (C) 2003-2013 TOMASZ KAxMIERCZAK\n"
 "                     COPYRIGHT (C) 2006 KAMIL PAWlOWSKI\n"
 "                     COPYRIGHT (C) 2009 MARCIN SeKALSKI\n"
 "                    COPYRIGHT (C) 2009 TOMASZ WIsNIEWSKI\n\n"
@@ -208,8 +208,8 @@ CCytadelaMenu::CCytadelaMenu() :
 
 	static const char *otherLang =
 "                               ...CYTADELA...\n"
-"                                 VERSION 1.0.1\n"
-"                 COPYRIGHT (C) 2003-2010 TOMASZ KAxMIERCZAK\n"
+"                                 VERSION 1.1.0\n"
+"                 COPYRIGHT (C) 2003-2013 TOMASZ KAxMIERCZAK\n"
 "                     COPYRIGHT (C) 2006 KAMIL PAWlOWSKI\n"
 "                     COPYRIGHT (C) 2009 MARCIN SeKALSKI\n"
 "                    COPYRIGHT (C) 2009 TOMASZ WIsNIEWSKI\n\n"
@@ -302,7 +302,7 @@ bool CCytadelaMenu::initMenu(const char **saveNames)
 
 	//fill the LOAD menu with savenames
 	for(int32_t i = 0; i < 5; ++i)
-		sprintf(mMenuTexts[MENU_LOAD][i], saveNames[i]);
+		sprintf(mMenuTexts[MENU_LOAD][i], "%s", saveNames[i]);
 
 	//fill the config-dependant menu positions
 	//OPTIONS MENU
@@ -311,13 +311,19 @@ bool CCytadelaMenu::initMenu(const char **saveNames)
 	if(mConfig->isDifficult())
 		text = mLocalization->getText(LOC_MENU_DIFFICULTY_HARD);
 	else text = mLocalization->getText(LOC_MENU_DIFFICULTY_EASY);
-	sprintf(mMenuTexts[MENU_SETTINGS][0], text);
+	sprintf(mMenuTexts[MENU_SETTINGS][0], "%s", text);
 	mMenuTextsXOffs[MENU_SETTINGS][0] = 120 - (strlen(text) * 8);
 	//screen size
 	const int32_t *screenSize = mConfig->getScreenSize();
 	sprintf(textBuffer, "%dX%d", screenSize[0], screenSize[1]);
-	sprintf(mMenuTexts[MENU_VIDEO][0], textBuffer);
+	sprintf(mMenuTexts[MENU_VIDEO][0], "%s", textBuffer);
 	mMenuTextsXOffs[MENU_VIDEO][0] = 120 - (strlen(textBuffer) * 8);
+	//fullscreen setting
+	if(mConfig->isFullScreen())
+		text = mLocalization->getText(LOC_MENU_FULLSCREEN);
+	else text = mLocalization->getText(LOC_MENU_WINDOWED);
+	sprintf(mMenuTexts[MENU_VIDEO][1], "%s", text);
+	mMenuTextsXOffs[MENU_VIDEO][1] = 120 - (strlen(text) * 8);
 
 	//SPEED SETTINGS menu
 	//get the game speed setting from the config - not used any more
@@ -334,7 +340,7 @@ bool CCytadelaMenu::initMenu(const char **saveNames)
 
 	//audio settings
 	bool audio = mConfig->getAudioStatus();
-	sprintf(mMenuTexts[MENU_AUDIO][0], audio ? mLocalization->getText(LOC_YES) : mLocalization->getText(LOC_NO));
+	sprintf(mMenuTexts[MENU_AUDIO][0], "%s", audio ? mLocalization->getText(LOC_YES) : mLocalization->getText(LOC_NO));
 	mMenuTextsXOffs[MENU_AUDIO][0] = 120 - (strlen(mMenuTexts[MENU_AUDIO][0]) * 8);
 
 	//at the begining we are in main menu on the first position
@@ -427,7 +433,7 @@ MenuAction CCytadelaMenu::enter()
 						text = mLocalization->getText(LOC_MENU_DIFFICULTY_HARD);
 					else
 						text = mLocalization->getText(LOC_MENU_DIFFICULTY_EASY);
-					sprintf(mMenuTexts[MENU_SETTINGS][0], text);
+					sprintf(mMenuTexts[MENU_SETTINGS][0], "%s", text);
 					mMenuTextsXOffs[MENU_SETTINGS][0] = 120 - (strlen(text) * 8);
 					updateMenuScreen();
 					break;
@@ -476,6 +482,8 @@ MenuAction CCytadelaMenu::enter()
 		case MENU_VIDEO: {
 			if(mSelItem == 0)
 				changeScreenSize();
+			if(mSelItem == 1)
+				toggleFullScreen();
 			if(mSelItem == 5) {
 				mMenu = MENU_SETTINGS;
 				mSelItem = 1;
@@ -557,6 +565,21 @@ void CCytadelaMenu::changeScreenSize()
 	updateMenuScreen();
 }
 
+void CCytadelaMenu::toggleFullScreen()
+{
+	const char *text;
+	if(mConfig->toggleFullScreen()) {
+		mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, CSDLClass::Mode2D, CSDLClass::FullScreen);
+		text = mLocalization->getText(LOC_MENU_FULLSCREEN);
+	} else {
+		mSDL->switchVideoMode(CSDL_DEFAULT_SCREEN_W, CSDL_DEFAULT_SCREEN_H, CSDLClass::Mode2D, CSDLClass::Windowed);
+		text = mLocalization->getText(LOC_MENU_WINDOWED);
+	}
+	sprintf(mMenuTexts[MENU_VIDEO][1], "%s", text);
+	mMenuTextsXOffs[MENU_VIDEO][1] = 120 - (strlen(text) * 8);
+	updateMenuScreen();
+}
+
 void CCytadelaMenu::changeGameSpeed()
 {
 	mConfig->setNextGameSpeed();
@@ -578,7 +601,7 @@ void CCytadelaMenu::changeMouseSpeed()
 void CCytadelaMenu::changeAudioStatus()
 {
 	bool audio = mConfig->changeAudioStatus();
-	sprintf(mMenuTexts[MENU_AUDIO][0], audio ? mLocalization->getText(LOC_YES) : mLocalization->getText(LOC_NO));
+	sprintf(mMenuTexts[MENU_AUDIO][0], "%s", audio ? mLocalization->getText(LOC_YES) : mLocalization->getText(LOC_NO));
 	mMenuTextsXOffs[MENU_AUDIO][0] = 120 - (strlen(mMenuTexts[MENU_AUDIO][0]) * 8);
 	updateMenuScreen();
 
