@@ -1,9 +1,6 @@
 /*
   File name: COGLClass.cpp
-  Copyright: (C) 2005 - 2009 Tomasz Kazmierczak
-
-  Creation date: 18.07.2005 15:48
-  Last modification date: 01.11.2009
+  Copyright: (C) 2005 - 2013 Tomasz Kazmierczak
 
   This file is part of Cytadela
 
@@ -63,7 +60,7 @@ bool COGLClass::initOGL(GLsizei width, GLsizei height)
 	//fog
 	glEnable(GL_FOG);
 	glFogi(GL_FOG_MODE, GL_EXP2);
-	glFogf(GL_FOG_DENSITY, 0.0006f);
+	glFogf(GL_FOG_DENSITY, 0.0007f);
 	float color[] = {0.188f, 0.188f, 0.188f, 1.0f};
 	glFogfv(GL_FOG_COLOR, color);
 	glHint(GL_FOG_HINT, GL_NICEST);
@@ -404,23 +401,24 @@ bool transpSort(Mesh3Dg *mesh1, Mesh3Dg *mesh2)
 void COGLClass::drawMeshes()
 {
 	//floor and celling (render 'em here 'cause they wouldn't pass the visiblity test
-	//in some cases and they should be visible always); they will be re-rendered in
-	//the opaque meshes rendering loop, but it's ok
-	MeshBase3Dg *base = mObjects->meshes[0]->getBase();
+	//in some cases and they should be visible always)
+	MeshBase3Dg *floorBase = mObjects->meshes[0]->getBase();
 	setTextures(mObjects->meshes[0]);
-	glVertexPointer(3, GL_FLOAT, 0, base->getVCoordsStream());
-	glDrawArrays(GL_TRIANGLES, 0, base->getTriansQuantity() * 3);
+	glVertexPointer(3, GL_FLOAT, 0, floorBase->getVCoordsStream());
+	glDrawArrays(GL_TRIANGLES, 0, floorBase->getTriansQuantity() * 3);
 
-	base = mObjects->meshes[1]->getBase();
+	MeshBase3Dg *ceilingBase = mObjects->meshes[1]->getBase();
 	setTextures(mObjects->meshes[1]);
-	glVertexPointer(3, GL_FLOAT, 0, base->getVCoordsStream());
-	glDrawArrays(GL_TRIANGLES, 0, base->getTriansQuantity() * 3);
+	glVertexPointer(3, GL_FLOAT, 0, ceilingBase->getVCoordsStream());
+	glDrawArrays(GL_TRIANGLES, 0, ceilingBase->getTriansQuantity() * 3);
 
 	for(Mesh3DgList::iterator i = mOpaqueMeshes.begin(); i != mOpaqueMeshes.end(); i++) {
 		Mesh3Dg *mesh = *i;
+		MeshBase3Dg *base = mesh->getBase();
+		if(base == floorBase or base == ceilingBase)
+			continue;
 		if(not mesh->getProperty(MRP_HAS_BASE) or not mesh->getProperty(MRP_RENDERABLE))
 			continue;
-		base = mesh->getBase();
 		//visiblity test
 		const Point3Dg *firstVertexCoords = base->getVCoordsStream();
 		//move back the camera cords a little to avoid culling objects that are
@@ -451,7 +449,7 @@ void COGLClass::drawMeshes()
 		Mesh3Dg *mesh = *i;
 		if(not mesh->getProperty(MRP_HAS_BASE) or not mesh->getProperty(MRP_RENDERABLE))
 			continue;
-		base = mesh->getBase();
+		MeshBase3Dg *base = mesh->getBase();
 		//visiblity test
 		const Point3Dg *firstVertexCoords = base->getVCoordsStream();
 		float fVx = mesh->translation.r4c1 + firstVertexCoords->x - (mX - 110.0f * mSin);
@@ -924,7 +922,7 @@ void COSDClass::addText(const char *text)
 	if(osdTextLen + newChars > 127)
 		return;
 	mIncomingChars += newChars;
-	sprintf(&mOSDText[osdTextLen], text);
+	sprintf(&mOSDText[osdTextLen], "%s", text);
 	mTextScrollSpeed = 0.4f;
 }
 
