@@ -1,6 +1,6 @@
 /*
   File name: CSDLClass.cpp
-  Copyright: (C) 2005 - 2010 Tomasz Kazmierczak
+  Copyright: (C) 2005 - 2013 Tomasz Kazmierczak
 
   This file is part of Cytadela
 
@@ -33,7 +33,7 @@ CSDLClass *CSDLClass::instance()
 CSDLClass::CSDLClass() : mScreen(0), mJoystick(0), mMusic(0), mAudioAvailable(false),
 	mAudioEnabled(true), mLoadedSoundsCount(0), mMenuMouseXPos(0), mMenuMouseYPos(0),
 	mLastMouseInputTime(0), mLastJoyInputTime(0), mScreenSizesCount(0),
-	mScreenSizes(0)
+	mScreenSizes(0), mScreenMode(FullScreen)
 {
 	memset(mSounds, 0, sizeof(mSounds));
 }
@@ -66,12 +66,14 @@ bool CSDLClass::init()
 	                              {{"800", "600"}, {800, 600}, true},
 	                              {{"1024", "768"}, {1024, 768}, true},
 	                              {{"1152", "864"}, {1152, 864}, true},
+	                              {{"1280", "720"}, {1280, 720}, true},
 	                              {{"1280", "800"}, {1280, 800}, true},
 	                              {{"1280", "960"}, {1280, 960}, true},
 	                              {{"1280", "1024"}, {1280, 1024}, true},
 	                              {{"1366", "768"}, {1366, 768}, true},
 	                              {{"1600", "1024"}, {1600, 1024}, true},
 	                              {{"1600", "1200"}, {1600, 1200}, true},
+	                              {{"1920", "1080"}, {1920, 1080}, true},
 	                              {{"1920", "1200"}, {1920, 1200}, true},
 	                              {{"2048", "1536"}, {2048, 1536}, true}};
 	bool anySizeAvailable = false;
@@ -95,10 +97,7 @@ bool CSDLClass::init()
 	}
 	mScreenSizes = sizes;
 
-#if not defined(DEBUG)
  	SDL_ShowCursor(SDL_DISABLE);
- 	SDL_WM_GrabInput(SDL_GRAB_ON);
-#endif
 
 	//if there is a joystick then we enable it's events and open it
 	mJoystick = 0;
@@ -118,20 +117,21 @@ bool CSDLClass::init()
 	return true;
 }
 
-bool CSDLClass::switchVideoMode(int32_t width, int32_t height, VideoMode mode)
+bool CSDLClass::switchVideoMode(int32_t width, int32_t height, VideoMode vmode, ScreenMode smode)
 {
-#if defined(DEBUG)
-	uint32_t flags = SDL_HWSURFACE;
-#else
-	uint32_t flags = SDL_HWSURFACE | SDL_FULLSCREEN;
-#endif
+	if(smode != NoChange)
+		mScreenMode = smode;
 
-	switch(mode) {
-		case MODE_2D: {
+	uint32_t flags = SDL_HWSURFACE;
+	if(mScreenMode == FullScreen)
+		flags |= SDL_FULLSCREEN;
+
+	switch(vmode) {
+		case Mode2D: {
 			flags |= SDL_DOUBLEBUF;
 			break;
 		}
-		case MODE_3D: {
+		case Mode3D: {
 			//attribs for OGL
 			SDL_GL_SetAttribute(SDL_GL_DEPTH_SIZE, 24);
 			SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1);
