@@ -1,9 +1,6 @@
 /*
   File name: Localization.cpp
-  Copyright: (C) 2006 - 2008 Tomasz Kazmierczak
-
-  Creation date: 02.06.2006
-  Last modification date: 22.10.2008
+  Copyright: (C) 2006 - 2013 Tomasz Kazmierczak
 
   This file is part of Cytadela
 
@@ -75,6 +72,10 @@ void Localization::setDefaultLocalization()
 		mLocalizedTexts[LOC_MENU_DIFFICULTY_EASY] = "TRUDNOsc MAlA";
 	if(not mLocalizationAvailable[LOC_MENU_VIDEO_OPTIONS])
 		mLocalizedTexts[LOC_MENU_VIDEO_OPTIONS] = "OPCJE GRAFICZNE";
+	if(not mLocalizationAvailable[LOC_MENU_FULLSCREEN])
+		mLocalizedTexts[LOC_MENU_FULLSCREEN] = "PElNY EKRAN";
+	if(not mLocalizationAvailable[LOC_MENU_WINDOWED])
+		mLocalizedTexts[LOC_MENU_WINDOWED] = "OKNO";
 	if(not mLocalizationAvailable[LOC_MENU_SPEED_SETTINGS])
 		mLocalizedTexts[LOC_MENU_SPEED_SETTINGS] = "UST. SZYBKOsCI";
 
@@ -591,7 +592,7 @@ bool Localization::loadLocalization(char *localization, CInfoText *infoTexts)
 	//chosen language
 	setDefaultLocalization();
 	//set the current localization name
-	sprintf(mCurrentLocalization, localization);
+	sprintf(mCurrentLocalization, "%s", localization);
 	return true;
 }
 
